@@ -974,11 +974,17 @@ typedef struct sdla
 	* rsync timeout, it should be long */
 	wan_ticks_t   rsync_timeout;
 
+	/* This value is used for detecting Fronte end interrupt
+	* timeout, it should be long */
+	wan_ticks_t   front_end_irq_timeout;
+
 	/* SDLA TDMV Dummy interface */
 #if defined(CONFIG_PRODUCT_WANPIPE_TDM_VOICE)
         void* sdla_tdmv_dummy;
 #endif
 
+	unsigned char wp_debug_chan_seq;
+
 } sdla_t;
 
 /****** Public Functions ****************************************************/
